==> ginkgo-hpc-docs-1.7.0-5-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_15.js <==
var searchData=
[
  ['window_0',['window',['../classgko_1_1experimental_1_1mpi_1_1window.html',1,'gko::experimental::mpi']]],
  ['workspace_5ftraits_1',['workspace_traits',['../structgko_1_1solver_1_1workspace__traits.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20bicg_3c_20valuetype_20_3e_20_3e_2',['workspace_traits&lt; Bicg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20bicgstab_3c_20valuetype_20_3e_20_3e_3',['workspace_traits&lt; Bicgstab&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20cg_3c_20valuetype_20_3e_20_3e_4',['workspace_traits&lt; Cg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20cgs_3c_20valuetype_20_3e_20_3e_5',['workspace_traits&lt; Cgs&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20fcg_3c_20valuetype_20_3e_20_3e_6',['workspace_traits&lt; Fcg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gcr_3c_20valuetype_20_3e_20_3e_7',['workspace_traits&lt; Gcr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gko_3a_3aexperimental_3a_3asolver_3a_3adirect_3c_20valuetype_2c_20indextype_20_3e_20_3e_8',['workspace_traits&lt; gko::experimental::solver::Direct&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gmres_3c_20valuetype_20_3e_20_3e_9',['workspace_traits&lt; Gmres&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gmres_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20idr_3c_20valuetype_20_3e_20_3e_10',['workspace_traits&lt; Idr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20ir_3c_20valuetype_20_3e_20_3e_11',['workspace_traits&lt; Ir&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Ir_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20lowertrs_3c_20valuetype_2c_20indextype_20_3e_20_3e_12',['workspace_traits&lt; LowerTrs&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01LowerTrs_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20multigrid_20_3e_13',['workspace_traits&lt; Multigrid &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Multigrid_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20uppertrs_3c_20valuetype_2c_20indextype_20_3e_20_3e_14',['workspace_traits&lt; UpperTrs&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01UpperTrs_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['writabletomatrixdata_15',['WritableToMatrixData',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20default_5fprecision_2c_20int32_20_3e_16',['WritableToMatrixData&lt; default_precision, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20default_5fprecision_2c_20int64_20_3e_17',['WritableToMatrixData&lt; default_precision, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20double_20_3e_2c_20int32_20_3e_18',['WritableToMatrixData&lt; std::complex&lt; double &gt;, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20double_20_3e_2c_20int64_20_3e_19',['WritableToMatrixData&lt; std::complex&lt; double &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int32_20_3e_20',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int64_20_3e_21',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20value_5ftype_2c_20int32_20_3e_22',['WritableToMatrixData&lt; value_type, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20value_5ftype_2c_20int64_20_3e_23',['WritableToMatrixData&lt; value_type, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]]
];

==> ginkgo-hpc-docs-1.8.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_15.js <==
var searchData=
[
  ['window_0',['window',['../classgko_1_1experimental_1_1mpi_1_1window.html',1,'gko::experimental::mpi']]],
  ['workspace_5ftraits_1',['workspace_traits',['../structgko_1_1solver_1_1workspace__traits.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20bicg_3c_20valuetype_20_3e_20_3e_2',['workspace_traits&lt; Bicg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20bicgstab_3c_20valuetype_20_3e_20_3e_3',['workspace_traits&lt; Bicgstab&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20cg_3c_20valuetype_20_3e_20_3e_4',['workspace_traits&lt; Cg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20cgs_3c_20valuetype_20_3e_20_3e_5',['workspace_traits&lt; Cgs&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20fcg_3c_20valuetype_20_3e_20_3e_6',['workspace_traits&lt; Fcg&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gcr_3c_20valuetype_20_3e_20_3e_7',['workspace_traits&lt; Gcr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gko_3a_3aexperimental_3a_3asolver_3a_3adirect_3c_20valuetype_2c_20indextype_20_3e_20_3e_8',['workspace_traits&lt; gko::experimental::solver::Direct&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20gmres_3c_20valuetype_20_3e_20_3e_9',['workspace_traits&lt; Gmres&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Gmres_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20idr_3c_20valuetype_20_3e_20_3e_10',['workspace_traits&lt; Idr&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20ir_3c_20valuetype_20_3e_20_3e_11',['workspace_traits&lt; Ir&lt; ValueType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Ir_3_01ValueType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20lowertrs_3c_20valuetype_2c_20indextype_20_3e_20_3e_12',['workspace_traits&lt; LowerTrs&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01LowerTrs_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20multigrid_20_3e_13',['workspace_traits&lt; Multigrid &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01Multigrid_01_4.html',1,'gko::solver']]],
  ['workspace_5ftraits_3c_20uppertrs_3c_20valuetype_2c_20indextype_20_3e_20_3e_14',['workspace_traits&lt; UpperTrs&lt; ValueType, IndexType &gt; &gt;',['../structgko_1_1solver_1_1workspace__traits_3_01UpperTrs_3_01ValueType_00_01IndexType_01_4_01_4.html',1,'gko::solver']]],
  ['writabletomatrixdata_15',['WritableToMatrixData',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20default_5fprecision_2c_20int32_20_3e_16',['WritableToMatrixData&lt; default_precision, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20default_5fprecision_2c_20int64_20_3e_17',['WritableToMatrixData&lt; default_precision, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20double_20_3e_2c_20int32_20_3e_18',['WritableToMatrixData&lt; std::complex&lt; double &gt;, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20double_20_3e_2c_20int64_20_3e_19',['WritableToMatrixData&lt; std::complex&lt; double &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int32_20_3e_20',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20std_3a_3acomplex_3c_20float_20_3e_2c_20int64_20_3e_21',['WritableToMatrixData&lt; std::complex&lt; float &gt;, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20value_5ftype_2c_20int32_20_3e_22',['WritableToMatrixData&lt; value_type, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20value_5ftype_2c_20int64_20_3e_23',['WritableToMatrixData&lt; value_type, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20valuetype_2c_20int32_20_3e_24',['WritableToMatrixData&lt; ValueType, int32 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]],
  ['writabletomatrixdata_3c_20valuetype_2c_20int64_20_3e_25',['WritableToMatrixData&lt; ValueType, int64 &gt;',['../classgko_1_1WritableToMatrixData.html',1,'gko']]]
];
